#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-engine
version:              0.4
visibility:           public
id:                   pandoc-lua-engine-0.4-6fuKHVAWkb69XOt1NmzixI
key:                  pandoc-lua-engine-0.4-6fuKHVAWkb69XOt1NmzixI
license:              GPL-2.0-or-later
copyright:            © 2006-2024 John MacFarlane, 2017-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  869f7085714c47192090699fc2e5803b
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Engine
    Text.Pandoc.Lua.Filter Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Module Text.Pandoc.Lua.Marshal.Chunks
    Text.Pandoc.Lua.Marshal.CommonState Text.Pandoc.Lua.Marshal.Context
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.ImageSize
    Text.Pandoc.Lua.Marshal.LogMessage
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.Image
    Text.Pandoc.Lua.Module.JSON Text.Pandoc.Lua.Module.Log
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Run
    Text.Pandoc.Lua.SourcePos Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.4-6fuKHVAWkb69XOt1NmzixI
depends:
    aeson-2.2.1.0-JgWKiJCfYvV9emVBTyf17S base-4.18.2.1
    bytestring-0.11.5.3 citeproc-0.8.1.1-73sKRPzLJKCDHG6PCvROvG
    containers-0.6.7 crypton-1.0.4-218iYZKZyEH9qzNK0rIxzf
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    doclayout-0.5-BJFC75tKV1gHUhcmhkiJa8
    doctemplates-0.11.0.1-9NWQCp6M7hbG2sHERn3QJ3 exceptions-0.10.7
    hslua-2.3.0-Es2SZImmPsG3yIoSZMu3Py
    hslua-module-doclayout-1.2.0-EiMRExSvN419WoJkssXZEz
    hslua-module-path-1.1.1-60JT70FTpdcA9DM8MUmSgw
    hslua-module-system-1.1.2-IDRAUObs1XqC9Hu6Dv2p00
    hslua-module-text-1.1.0.1-CBJLKdH0o7sl0qfCLELpj
    hslua-module-version-1.1.1-El8mpNjJEtQFoAVAG3PxMy
    hslua-module-zip-1.1.3-97OKLtDd9npEOw4lpdhELY
    hslua-repl-0.1.2-9fcDrtRUjYW3qQdlvBkEjw
    lpeg-1.1.0-5TfHIBQobQKEgztB5q37ux mtl-2.3.1
    pandoc-3.6-AvHgV3fEtvN4y0ozdLHjbE
    pandoc-lua-marshal-0.3.0-DugV4LUgNpi2D5AZQ8nCXq
    pandoc-types-1.23.1-Hm26sICfqo87cdueYshD1K parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

